.. |buildstatus| image:: https://img.shields.io/travis/tooxie/shiva-server.png
    :alt: Build status
    :target: http://travis-ci.org/tooxie/shiva-server
.. |testcoverage| image:: https://img.shields.io/coveralls/tooxie/shiva-server.png
    :alt: Test coverage
    :target: https://coveralls.io/r/tooxie/shiva-server
.. |documentation| image:: https://readthedocs.org/projects/shiva/badge/?version=latest
    :alt: Documentation
    :target: http://shiva.readthedocs.org/en/latest/
.. |downloads| image:: https://img.shields.io/pypi/dm/shiva.png
    :alt: PyPi downloads
    :target: https://pypi.python.org/pypi/shiva


Shiva
=====

More than a RESTful API to your music collection.

|buildstatus| |testcoverage| |documentation| |downloads|


What is Shiva?
--------------

The Mozilla Hacks blog kindly published a nice article that explains the ideas
that inspire this software:
`Shiva: More than a RESTful API to your music collection
<https://hacks.mozilla.org/2013/03/shiva-more-than-a-restful-api-to-your-music-collection/>`_.

You can find the technical documentation at `Read The Docs
<http://shiva.readthedocs.org/en/latest/>`_.


Installation
------------

Read the instruction on `how to install Shiva
<http://shiva.readthedocs.org/en/latest/installation.html>`_ in the official
documentation.


License
-------

Please read the LICENSE file distributed with this software.


Disclaimer
----------

Remember that when using this software you must comply with your country's
laws. You and only you will be held responsible for any law infringement
resulting from the misuse of this software.

That said, have fun.


Why Shiva?
----------

Shiva is the name of the `crater <https://en.wikipedia.org/wiki/Shiva_crater>`_
that would have been created by the
`K-Pg event <https://en.wikipedia.org/wiki/Cretaceous%E2%80%93Paleogene_extinction_event>`_
that extincted the `dinosaurs <https://www.youtube.com/watch?v=dlAeN3Qxlvc>`_.
